RutokenDeviceEvent class

Constructors

RutokenDeviceEvent({required RutokenDeviceEventType type, required String name})
RutokenDeviceEvent.fromJSON(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type RutokenDeviceEventType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDevice() RutokenDevice
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited